import { Link } from "wouter";
import { Button } from "@/components/ui/button";
import { Menu, Youtube, Linkedin as LinkedinIcon } from "lucide-react";
import { GlobalSearchBar } from "./global-search-bar";
import { ThemeButton } from "../components/theme-button";
import { useIsMobile } from "@/hooks/use-mobile";
import { FaMedium, FaWhatsapp } from "react-icons/fa";
import r3pl1caDarkLogo from "@assets/r3pl1ca_dark.png";

interface HeaderProps {
  onSearch?: (query: string) => void; // Made optional since global search handles this directly
  onSidebarToggle?: () => void;
}

export function Header({ onSearch, onSidebarToggle }: HeaderProps) {
  const isMobile = useIsMobile();

  return (
    <header className="sticky top-0 z-40 bg-white dark:bg-black w-full border-0 md:border-b md:border-border">
      <div className="px-4 h-[60px] flex items-center max-w-7xl mx-auto">
        {/* Mobile Layout - 3 column layout: Menu | Logo | Theme Toggle */}
        {isMobile && (
          <>
            {/* Left: Menu button */}
            <div className="flex-none w-14">
              <Button 
                variant="ghost" 
                size="icon" 
                onClick={onSidebarToggle}
                aria-label="Toggle sidebar menu"
              >
                <Menu className="h-5 w-5" aria-hidden="true" />
              </Button>
            </div>
            
            {/* Center: Logo */}
            <div className="flex-1 flex justify-center">
              <Link 
                href="/intro" 
                className="font-bold text-primary text-xl tracking-tight"
                aria-label="R3PL1C4 homepage"
              >
                R3PL1C4
              </Link>
            </div>
            
            {/* Right: Theme toggle */}
            <div className="flex-none w-auto flex justify-end items-center gap-2">
              <ThemeButton />
            </div>
          </>
        )}
        
        {/* Desktop Layout */}
        {!isMobile && (
          <>
            {/* Central search bar */}
            <div 
              className="flex-1 pr-8 global-search"
              role="search"
              aria-label="Site-wide search"
            >
              <GlobalSearchBar 
                placeholder="Search AI or Robotics resources..." 
                className="w-full max-w-4xl"
              />
            </div>

            {/* Right section */}
            <div className="flex items-center gap-4">
              {/* Social Media Icons */}
              <div className="flex items-center space-x-3 mr-3">
                <a 
                  href="https://whatsapp.com/channel/0029VaAblRIFi8xWrxsiYi3Q" 
                  target="_blank" 
                  rel="noopener noreferrer" 
                  className="p-2 text-[#5a3fd6] hover:bg-[#5a3fd6]/10 rounded-full transition-colors"
                  aria-label="Follow us on WhatsApp (opens in new tab)"
                >
                  <FaWhatsapp className="h-5 w-5" aria-hidden="true" />
                </a>
                <a 
                  href="https://medium.com/r3plica" 
                  target="_blank" 
                  rel="noopener noreferrer" 
                  className="p-2 text-[#5a3fd6] hover:bg-[#5a3fd6]/10 rounded-full transition-colors"
                  aria-label="Read our articles on Medium (opens in new tab)"
                >
                  <FaMedium className="h-5 w-5" aria-hidden="true" />
                </a>
                <a 
                  href="https://www.youtube.com/@r3pl1c4_" 
                  target="_blank" 
                  rel="noopener noreferrer" 
                  className="p-2 text-[#5a3fd6] hover:bg-[#5a3fd6]/10 rounded-full transition-colors"
                  aria-label="Watch our videos on YouTube (opens in new tab)"
                >
                  <Youtube className="h-5 w-5" aria-hidden="true" />
                </a>
                <a 
                  href="https://www.linkedin.com/company/r3pl1c4" 
                  target="_blank" 
                  rel="noopener noreferrer" 
                  className="p-2 text-[#5a3fd6] hover:bg-[#5a3fd6]/10 rounded-full transition-colors"
                  aria-label="Connect with us on LinkedIn (opens in new tab)"
                >
                  <LinkedinIcon className="h-5 w-5" aria-hidden="true" />
                </a>
              </div>

              {/* Theme toggle */}
              <ThemeButton />
            </div>
          </>
        )}
      </div>

      {/* Mobile search bar - positioned fixed at top */}
      {isMobile && (
        <div 
          className="fixed top-[60px] left-0 right-0 px-2 pt-4 pb-4 bg-white dark:bg-black z-30 shadow-sm border-0 border-t-0 border-b-0 border-l-0 border-r-0" 
          style={{ borderBottom: 'none' }}
          role="search"
          aria-label="Mobile search"
        >
          <div className="rounded-md bg-gray-200 dark:bg-gray-800 px-3 py-2 border-0">
            <GlobalSearchBar 
              placeholder="Search AI or Robotics resources..." 
              className="w-full h-12" 
              noBorder={true} 
            />
          </div>
        </div>
      )}
    </header>
  );
}